@@ -457,8 +457,10 @@ def get_type(field_type) -> Union[Type, str]:
         if len(non_scalar_args) == 0:
             python_type = list
             if len(non_none_args) == 1:
-                # inner_type = non_none_args.pop()
-                python_type = list  # List[inner_type]
+                if none_type in args:
+                    python_type = non_none_args.pop()
+                else:
+                    python_type = list
 
         elif len(non_none_args) != 1:
             raise TypeError(
