@@ -4,7 +4,7 @@ from sqlalchemy import create_engine, inspect, MetaData
 from sqlalchemy.orm import sessionmaker, RelationshipProperty
 from sqlalchemy.orm.clsregistry import _ModuleMarker
 
-from sqlalchemy_orm.base.helper import HelperBase
+from sqlalchemy_orm.base.helper import Base
 from sqlalchemy_orm.query import Query
 from sqlalchemy_orm.session import Session
 from sqlalchemy_orm.utils import find_subclasses
@@ -15,14 +15,11 @@ class DatabaseException(BaseException):
 
 
 class Database:
-
     def __init__(self, url, session_cls=Session, query_cls=Query):
         self.url = url
         self.engine = create_engine(url)
         self.session_maker = sessionmaker(
-            class_=session_cls,
-            bind=self.engine,
-            query_cls=query_cls
+            class_=session_cls, bind=self.engine, query_cls=query_cls
         )
         self.declarative_base = None
 
@@ -31,26 +28,32 @@ class Database:
         ERD in dot format
         """
 
-        from sqlalchemy_orm.eralchemy.main import \
-            _intermediary_to_dot, \
-            all_to_intermediary
+        from sqlalchemy_orm.eralchemy.main import (
+            _intermediary_to_dot,
+            all_to_intermediary,
+        )
 
         tables, relationships = all_to_intermediary(
-            self.declarative_base.metadata,
-            schema="Schema"
+            self.declarative_base.metadata, schema="Schema"
         )
         output = _intermediary_to_dot(tables, relationships)
 
         if embed_html:
             # flake8: noqa
-            output = """
+            output = (
+                """
             <!DOCTYPE html><meta charset="utf-8"><body>
             <script src="https://d3js.org/d3.v5.min.js"></script>
             <script src="https://unpkg.com/@hpcc-js/wasm@0.3.11/dist/index.min.js"></script>
             <script src="https://unpkg.com/d3-graphviz@3.0.5/build/d3-graphviz.js"></script>
             <div id="graph" style="text-align: center;"></div>
             <script>d3.select("#graph").graphviz().renderDot('DOT');</script>
-            """.replace("DOT", output).replace('\n', '').replace('\r', '')
+            """.replace(
+                    "DOT", output
+                )
+                .replace("\n", "")
+                .replace("\r", "")
+            )
 
         return output
 
@@ -61,17 +64,12 @@ class Database:
         base.metadata.create_all(bind=self.engine, checkfirst=True)
         self.declarative_base = base
 
-    def create(
-            self,
-            *models,
-            create_relations=True,
-            create_polymorphic_parents=True
-    ):
+    def create(self, *models, create_relations=True, create_polymorphic_parents=True):
         if create_relations:
             models_with_relations = {*models}
 
             for model in models:
-                if issubclass(model, HelperBase):
+                if issubclass(model, Base):
                     models_with_relations.update(model.relations())
                     self.declarative_base = model.declarative_base
 
@@ -81,7 +79,7 @@ class Database:
             parents = set()
 
             for model in models:
-                if issubclass(model, HelperBase):
+                if issubclass(model, Base):
                     parents.update(model.parents())
 
             models.update(parents)
@@ -89,29 +87,23 @@ class Database:
         get_metadata(models).create_all(
             bind=self.engine,
             tables=[model.__table__ for model in models],
-            checkfirst=True
+            checkfirst=True,
         )
 
     def delete(self, *models):
         get_metadata(models).drop_all(
             bind=self.engine,
             tables=[model.__table__ for model in models],
-            checkfirst=True
+            checkfirst=True,
         )
 
     def wipe(self):
         meta = MetaData()
         meta.reflect(bind=self.engine)
-        meta.drop_all(
-            bind=self.engine,
-            tables=meta.sorted_tables,
-            checkfirst=True
-        )
+        meta.drop_all(bind=self.engine, tables=meta.sorted_tables, checkfirst=True)
 
         if not self.is_empty():
-            raise DatabaseException(
-                f"Database '{self}' was not empty after wipe."
-            )
+            raise DatabaseException(f"Database '{self}' was not empty after wipe.")
 
     def is_empty(self):
         table_names = inspect(self.engine).get_table_names()
@@ -141,7 +133,7 @@ class Database:
         for model_class in find_subclasses(base):
             module_marker = isinstance(model_class, _ModuleMarker)
 
-            is_abstract = model_class.__dict__.get('__abstract__', False)
+            is_abstract = model_class.__dict__.get("__abstract__", False)
 
             if module_marker or is_abstract:
                 continue
@@ -169,9 +161,7 @@ class Database:
                                 errors = True
             else:
                 if logger:
-                    logger.info(
-                        "Table '{table}' does not exist in db '{self.engine}'"
-                    )
+                    logger.info("Table '{table}' does not exist in db '{self.engine}'")
 
                 errors = True
 
@@ -192,7 +182,7 @@ def get_metadata(models: Iterable[object]):
     metadata = None
 
     for model in models:
-        if hasattr(model, 'metadata'):
+        if hasattr(model, "metadata"):
             if metadata is None:
                 metadata = model.metadata
 
