@@ -18,11 +18,8 @@ try:
 except ImportError:
 
     class OrderByBase(QueryAdapter):
-
         def __init__(
-                self,
-                key: str,
-                direction: OrderByDirection = OrderByDirection.asc
+            self, key: str, direction: OrderByDirection = OrderByDirection.asc
         ):
             """
             The `OrderBy` ObjectType describes an
@@ -40,13 +37,10 @@ else:
 
 
 class OrderBy(OrderByBase):
-
     def apply(self, query, entities=None):
-
         if len(entities) != 1:
             raise OrderByMultipleEntitiesException(
-                f"Cannot use a OrderBy when querying"
-                f" multiple models: '{entities}'"
+                f"Cannot use a OrderBy when querying" f" multiple models: '{entities}'"
             )
 
         model = entities[0]
