@@ -5,12 +5,13 @@ from sqlalchemy.ext.associationproxy import association_proxy
 from sqlalchemy.orm import relationship, validates, object_session
 from sqlalchemy.orm.decl_api import declared_attr
 
-from sqlalchemy_orm.base.helper import HelperBase
+from sqlalchemy_orm.base.helper import Base
 from sqlalchemy_orm.patterns.taggable import Taggable
 
 
-class TagBase(HelperBase):
-    tag: str
+class TagBase(Base):
+    id: uuid.UUID = uuid.uuid4
+    tag: str = ""
 
     __inheritance__ = False
     cached_mixin = None
@@ -21,7 +22,7 @@ class TagBase(HelperBase):
             return cls.cached_mixin
         tag_cls: Type[TagBase] = cls
 
-        class Mixin(Taggable, HelperBase):
+        class Mixin(Taggable, Base):
             cached_tag_association_cls = None
 
             @classmethod
@@ -39,12 +40,12 @@ class TagBase(HelperBase):
                     tag: tag_cls
                     parent: cls = None
 
-                    __tablename__ = cls.__tablename__ + '_tag'
+                    __tablename__ = cls.__tablename__ + "_tag"
                     __inheritance__ = False
 
                     @declared_attr
                     def tag_str(self):
-                        return association_proxy('tag', 'tag')
+                        return association_proxy("tag", "tag")
 
                     @validates("tag")
                     def _validate_tag(self, key, value):
@@ -52,9 +53,7 @@ class TagBase(HelperBase):
                         if session is not None:
                             v = value.value
                             with session.no_autoflush:
-                                uvalue = session.query(tag_cls) \
-                                    .filter_by(tag=v) \
-                                    .first()
+                                uvalue = session.query(tag_cls).filter_by(tag=v).first()
                                 if uvalue:
                                     session.expunge(value)
                                     return uvalue
@@ -73,8 +72,7 @@ class TagBase(HelperBase):
             @declared_attr
             def tag_associations(self):
                 return relationship(
-                    self.tag_association_cls(),
-                    cascade="all, delete, delete-orphan"
+                    self.tag_association_cls(), cascade="all, delete, delete-orphan"
                 )
 
             @validates("tag_associations")
@@ -83,9 +81,7 @@ class TagBase(HelperBase):
                 if session is not None:
                     tag = value.tag
                     with session.no_autoflush:
-                        existing_tag = session.query(tag_cls) \
-                            .filter_by(tag=tag) \
-                            .first()
+                        existing_tag = session.query(tag_cls).filter_by(tag=tag).first()
                         if existing_tag:
                             session.expunge(existing_tag)
                             value.tag = existing_tag
@@ -100,11 +96,7 @@ class TagBase(HelperBase):
                     # from context_helper import ctx
                     return TagAssociation(tag=Tag(tag=_tag))
 
-                return association_proxy(
-                    'tag_associations',
-                    'tag_str',
-                    creator=creator
-                )
+                return association_proxy("tag_associations", "tag_str", creator=creator)
 
         cls.cached_mixin = Mixin
         return Mixin
